Learn R Programming

bshazard (version 1.1)

print.bshazard: Print a short summary of the hazard rate

Description

Print number of observations, number of events, total person-time and overall rate of event.

Usage

# S3 method for bshazard
print(x,...)

Arguments

x

the result of a call to the bshazard function.

Value

Number of records

number of records in input data

...

covariate values

n.events

total number of events (for each covariate value)

person.time

total person-time (for each covariate value)

rate

overall rate

See Also

bshazard,summary.bshazard,plot.bshazard

Examples

Run this code
# NOT RUN {
data(lung,package="survival")
 fit<-bshazard(Surv(time, status==2) ~ 1,data=lung)
print(fit)    
# }

Run the code above in your browser using DataLab